---
name: Bug report
about: Create a report to help us improve memoprop
title: 'Bug Report:'
---

- [ ] I have checked the [Issue tracker](../issues) and as far as I can tell, this is not a duplicate issue
- [ ] I am using the latest version of memoprop


**Describe the bug**

A clear an concise description of what the bug is.


**To reproduce**

Steps to reproduce the behaviour, in a self contained snippet.

```python
>>> import memoprop
>>> ...
```


**Expected behaviour**

A clear, concise description of what you expected to happen.

- OS (e.g. Windows 10 (1903), OS X 10.8, Ubuntu 18.04 etc.)
- Python version (i.e. the result of `python --version`)
- Version: (i.e. the result of `python -c "import memoprop; memoprop.__version__" `)
- Installation method (conda, pip, source etc.)


**Additional information and context**

Any other information and context which might be of relevance.
